'##############################################################
' DN_RC5.BAS
'
' Empfang und Decodierung eines RC5-Signal einer Universal-IR-
' Fernbedienung und Ansteuerung von vier Relais schalten.
' Die Relais werden zum Steuern eines CD-Player ohne IR-Fern-
' bedienung verwendet.
' Mit der Baugruppe lassen sich aber beliebige Verbraucher, wie
' im Modellbau, Modelleisenbahn, Niedervoltlampen u.a. schalten.
'
' !!! In jedem Fall ist die Schaltleistung der Relais und der
' Strombedarf zu beachten.
' Der Strombedarf darf 15 mA nicht bersteigen !!!
'
' Chip: AT90S2313
' Xtal: 4 MHz
' IR-Sensor: SFH 506-36 oder TSOP 1736
' Relais: DR-5V-H14 oder DIP 7212-D 5V (wichtig RI min 500 Ohm)
'
' Autor: Dirk Neyen
'##############################################################

$regfile = "2313def.dat" 	' AT90S2313
$crystal = 4000000       	' Quarzfrequenz fr SP12-(T)WinAvr
$baud = 19200 		      		  ' Baudrate

Config Rc5 = Pind.2     		' PD2 ist Eingang fr TSOP 1736
Portd.2 = 1         	  			' Pullup aktiv

Config Pind.3 = Output   	' PD3 ist Ausgang fr Relais 1
Portd.3 = 1 			          	' PD3 = 5 V, Relais 1 nicht angezogen
Config Pind.4 = Output  		' PD4 ist Ausgang fr Relais 2
Portd.4 = 1         			  	' PD4 = 5 V, Relais 2 nicht angezogen
Config Pind.5 = Output  		' PD5 ist Ausgang fr Relais 3
Portd.5 = 1 	          			' PD5 = 5 V, Relais 3 nicht angezogen
Config Pind.6 = Output  		' PD6 ist Ausgang fr Relais 4
Portd.6 = 1             		' PD6 = 5 V, Relais 4 nicht angezogen

Declare Sub Pulse(byval Io As Byte , Byval Repeat As Byte)

Dim Address As Byte , Command As Byte
Dim X As Byte , A As Byte

Enable Interrupts      			' Timer0 arbeitet im Hintergrund

Print "Warte auf RC5 signal..."

Do

  Getrc5(address , Command)		' Einlesen des RC5-Signals
  Reset Command.6            ' Reset Toggle-Bit

  If Address = 20 Then     		' Prfen, ob Addresse 20 ist

   	Print Address ; "  " ; Command  	' Ausgabe von Addresse u. Command
                                    	' wird nur zum Testen gebraucht.

   	If Command = 54 Then  	 	' Prfen, ob die "Stop" Taste gedrckt wurde
    		Print "STOP"
    		Pulse 3 , 1
   	End If

   	If Command = 48 Then 	  	' Prfen, ob die "Pause" Taste gedrckt wurde
    		Print "PAUSE"
    		Pulse 4 , 1
   	End If

   	If Command = 53 Then	   	' Prfen, ob die "Play" Taste gedrckt wurde
    		Print "PLAY"
    		Pulse 4 , 1
   	End If

   	If Command = 52 Then   		' Prfen, ob die ">>" Taste gedrckt wurde
    		Print ">>"
    		Pulse 5 , 1
   	End If

   	If Command = 50 Then    	' Prfen, ob die "<<" Taste gedrckt wurde
    		Print "<<"
    		Pulse 6 , 1
   	End If

   	If Command = 0 Then    		' Prfen, ob die "0" Taste gedrckt wurde
    		Print "0 => STEP x 10"	' dann Relais 3 10x ein- und ausschalten
    		Pulse 5 , 10
   	End If

   	If Command = 5 Then    		' Prfen, ob die "5" Taste gedrckt wurde
    		Print "5 => STEP x 5" 	' dann Relais 3 5x ein- und ausschalten
    		Pulse 5 , 5
   	End If
 	End If
Loop
End


Sub Pulse(io , Repeat )    		' Relaisansteuerung

Local I As Byte

For I = 1 To Repeat
 	Portd.io = 0
 	Waitms 250
 	Portd.io = 1
 	Waitms 250
Next
End Sub